#
# spec file for package urlwatch
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           urlwatch
Version:        2.16
Release:        1.1
Summary:        A tool for monitoring webpages for updates
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Utilities
Url:            https://thp.io/2008/urlwatch/
Source0:        https://github.com/thp/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  python-futures
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python-keyring
Requires:       python3-PyYAML
Requires:       python3-appdirs
Requires:       python3-lxml
Requires:       python3-minidb
Requires:       python3-requests
BuildArch:      noarch
Requires:       python-futures

%description
urlwatch is intended to help you watch changes in webpages and get
notified (via email, in your terminal or with a custom-written
reporter class) of any changes. The change notification will include
the URL that has changed and a unified diff of what has changed.


A default config is ~/.urlwatch/urlwatch.yaml.
use "urlwatch --edit-config" to customize it.

You need to create ~/.urlwatch/urls.yaml in order to use urlwatch.
Use "urlwatch --edit" to open the file with your editor.

Please look in

 /usr/share/doc/packages/urlwatch/README.md

 TIPS AND TRICKS what to use in urls.yaml.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGELOG* README*
%license COPYING*
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{_datadir}/%{name}

%changelog
* Mon Jan 28 2019 mvetter@suse.com
- Update to 2.16:
  * Added XPath: Handle /text() selector (#282)
  * Added document how to specify cookies to README.md (#264)
  * Added text Reporter: minimal config option to only print a summary (PR#304, fixes #147)
  * Added README.md: Document how to watch Github releases via XPath (#266)
  * Added jupport for parsing XML/RSS with XPath (Fixes #281)
  * Allow explicit setting of encoding for URL jobs (PR#313, contributes to #306)
  * Added Slack Channel Reporter (PR#309)
  * Added ANSI color output on the Windows console via colorama (PR#296, closes #295)
  * Added support for using CSS selectors via the cssselect module (PR#321, closes 273)
  * ignore_http_error_codes is now an option for URL jobs (PR#325, fixes #203)
  * Added job_defaults in the config for globally specifying settings (PR#345, closes #253)
  * Added Optional timeout (in seconds) for URL jobs to specify socket timeout (PR#348, closes #340)
  * Remvoed support for JSON storage (dead code that was never used in production; PR#336)
  * HtmlReporter now also highlights links for browser jobs (PR#303)
  * Allow --features and --edit-* to run without urls.yaml (PR#301)
  * When a previous run had errors, do not use conditional GETs (PR#313, fixes #292)
  * Explicitly specify JSON pretty print separators for consistency (PR#343)
  * Use data-driven unit tests/fixtures for easier unit test maintenance (PR#344)
  * Fix migration issues with case-insensitive filesystems (#223)
  * Correctly reset retry counter when job is added or unchanged (PR#291, PR#314)
  * Fix a FutureWarning on Python 3.7 with regard to regular expressions (PR#299)
  * If the filter list is empty, do not process the filter list (PR#308)
  * Fix parsing/sanity-checking of urls.yaml after editing (PR#317, fixes #316)
  * Fix Python 3.3 compatibility by depending on enum34 there (PR#311)
  * Fix migration issues introduced by PR#180 and #256 (PR#323, fixes #267)
* Wed Oct 24 2018 mvetter@suse.com
- Update to 2.15:
  * Added support for Mailgun regions (by Daniel Peukert, PR#280)
  * Added allowing multiple occurences of 'filter' when adding jobs in CLI (PR#278)
  * Fixed incorrect name for chat_id config in the default config (by Robin B, PR#276)
* Mon Oct 15 2018 Karol Babioch <kbabioch@suse.com>
- Added missing runtime dependency: python3-lxml (bsc#1111796)
* Tue Sep  4 2018 mvetter@suse.com
- Update to 2.14:
  * Added filter to pretty-print JSON data: format-json (by Niko Böckerman, PR#250)
  * Added list active Telegram chats using --telegram-chats (with fixes by Georg Pichler, PR#270)
  * Added support for HTTP ETag header in URL jobs and If-None-Match (by Karol Babioch, PR#256)
  * Added xupport for filtering HTML using XPath expressions, with lxml (PR#274, Fixes #226)
  * Added install_dependencies to setup.py commands for easy installing of dependencies
  * Added ignore_connection_errors per-job configuration option (by Karol Babioch, PR#261)
  * Improved code (HTTP status codes, by Karol Babioch PR#258)
  * Improved documentation for setting up Telegram chat bots
  * Allow multiple chats for Telegram reporting (by Georg Pichler, PR#271)
* Wed Jun  6 2018 kbabioch@suse.com
- Update to 2.13:
  * Added support for specifying a `diff_tool` (e.g. `wdiff`) for each job
  * Added support for testing filters via `--test-filter JOB`
  * Remove default parameter from internal `html2text` module (Fixes #239)
  * Better error/exception reporting in `--verbose` mode (Fixes #164)
- Update to 2.12:
  * Bugfix: Do not 'forget' old data if an exception occurs
* Tue May 22 2018 kbabioch@suse.com
- Update to 2.11:
  * Retry: Make sure "tries" is initialized to zero on load
  * html2text: Make sure the bs4 method strips HTML tags (by Louis Sautier)
- Marked COPYING file as %%license
* Fri May 18 2018 kbabioch@suse.com
- Update to 2.10:
  * File editing: Fix issue when $EDITOR contains spaces
  * Browser: Add support for browser jobs using requests-html
  * Retry: Add support for optional retry count in job list
  * HTTP: Add support for specifying optional headers
* Mon Mar 26 2018 kbabioch@suse.com
- Update to 2.9:
  * Pushover: Device and sound attribute
  * XDG: Move cache file to XDG_CACHE_DIR
  * E-Mail: Add support for --smtp-login and document GMail SMTP usage
  * Unconditionally migrate urlwatch 1.x cache dirs
* Wed Jan 31 2018 kbabioch@suse.com
- Update to 2.8, please see
  /usr/share/doc/packages/urlwatch/ChangeLog
- Added python3-appdirs as dependency
* Thu Jan 12 2017 mardnh@gmx.de
- Update to 2.6
  * New filters: sha1sum, hexdump, element-by-class
  * New reporters: pushbullet; mailgun
  * Improved filters: BeautifulSoup support for html2txt
  * Improved handlers: HTTP Proxy; support for file:// URIs
  * CI Integration: Build configuration for Travis CI
  * Consistency: Feature list is now sorted by name
  * Issue #108: Fix creation of example files on first startup
  * Issue #118: Fix match filters for missing keys
  * Small fixes
* Tue Jul 12 2016 nemysis@openSUSE.org
- Update to 2.5, please see
  /usr/share/doc/packages/urlwatch/ChangeLog
* Fri Feb 26 2016 nemysis@openSUSE.org
- Change Requires use python3-minidb instead of minidb
* Wed Feb 24 2016 nemysis@openSUSE.org
- Update to 2.1, please see
  /usr/share/doc/packages/urlwatch/ChangeLog
- Change BuildRequires, changed by Upstream for python3-devel
- Remove BuildRequires for fdupes, not need for it
- Add BuildRequires for python3-setuptools
- Add Requires for minidb, python-keyring, python3-PyYAML and
  python3-requests
- Change Description
- Add README.md to Documentation
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 1.18
  * Fallback to using pwd if os.getlogin() fails (fixes #2)
  * Handle HTTP compression (Content-encoding: gzip/deflate)
  * Add option to suppress output on stdout (-q/--quiet)
  * Allow customizing subject when sending e-mail (-S/--subject)
  * Added support for TLS and SMTP auth (-p/--pass, -T/--tls, -A/--auth)
  * Added support for specifying cache directory (-c/--cache)
  * Add support for HTTP Auth to urlwatch.handler (fixes #10)
* Sat Aug  2 2014 dmitry_r@opensuse.org
- Initial package, version 1.17
